package
Version:
v0.3.2
Opens a new window with list of versions in this module.
Published: May 21, 2020
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Handler interface {
OnConnect(cc conn.Conn)
SliceIndex(b []byte) int
OnWork(b []byte, writeChan chan<- []byte) error
OnWorkProcessStop()
OnReadProcessStop()
OnWriteProcessStop()
OnWriteFinish(b []byte)
OnWriteError(b []byte, err error) (ifExit bool)
OnClose()
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.